@@ -8,6 +8,7 @@
 #include "scan/scan_ulong.c"
 #include "scan/scan_ulongn.c"
 #include "fmt/fmt_utf8.c"
+#include "fmt/fmt_tohex.c"
 #include "fmt/fmt_escapecharc.c"
 
 char tmp[20];
@@ -196,6 +197,7 @@ int main() {
 #endif
       if (*s==']') break;
     } while (*s==',');
+    (*cur)->utf8[ul]=0;
 #if 0
     puts("\" },");
 #endif
@@ -207,7 +209,7 @@ int main() {
   {
     FILE* f=fopen("entities.h","w");
     size_t i;
-    fprintf(f,"struct {\n  uint32_t tab[%lu];\n  char data[%lu];\n} entities = {\n  {",marshaled[0],datasize);
+    fprintf(f,"struct {\n  uint32_t tab[%u];\n  char data[%lu];\n} entities = {\n  {",marshaled[0],datasize);
     for (i=0; i<marshaled[0]; ++i) {
       if (i%8 == 0) fprintf(f,"\n    ");
       fprintf(f,"0x%x,",marshaled[i]);
