@@ -28,7 +28,7 @@ char* mmap_private(const char* filename,size_t * filesize) {
   char *map;
   if (fd>=0) {
     register off_t o=lseek(fd,0,SEEK_END);
-    if (sizeof(off_t)!=sizeof(size_t) && o > (off_t)(size_t)-1) { close(fd); return 0; }
+    if (o==0 || (sizeof(off_t)!=sizeof(size_t) && o > (off_t)(size_t)-1)) { close(fd); return 0; }
     *filesize=(size_t)o;
     map=(char*)mmap(0,*filesize,PROT_READ|PROT_WRITE,MAP_PRIVATE,fd,0);
     if (map==(char*)-1)
