@@ -11,11 +11,15 @@ size_t scan_longn(const char *src,size_t n,long *dest) {
   if (!n--) return 0;
   tmp=src; l=0; ok=0; neg=0;
   switch (*tmp) {
-  case '-': neg=1;
+  case '-': neg=1; /* fall through */
   case '+': ++tmp;
   }
   while (n-->0 && (c=(unsigned char)(*tmp-'0'))<10) {
     unsigned long int n;
+#if defined(__GNUC__) && (__GNUC__ >= 5)
+    if (__builtin_mul_overflow(l,10,&n) || __builtin_add_overflow(n,c,&n))
+      break;
+#else
     /* we want to do: l=l*10+c
      * but we need to check for integer overflow.
      * to check whether l*10 overflows, we could do
@@ -28,6 +32,7 @@ size_t scan_longn(const char *src,size_t n,long *dest) {
     n+=(unsigned long)l<<1;
     if (n+c < n) break;
     n+=c;
+#endif
     if (n > maxlong+neg) break;
     l=(long)n;
     ++tmp;
